@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 2005-2021 Massachusetts Institute of Technology
+/* Copyright (C) 2005-2022 Massachusetts Institute of Technology
 %
 %  This program is free software; you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -46,7 +46,11 @@ private:
 #define PRINTF_ATTR(f, a)
 #endif
 
+#ifdef SWIG
 void abort(const char *fmt, ...) PRINTF_ATTR(1, 2);
+#else
+[[noreturn]] void abort(const char *fmt, ...) PRINTF_ATTR(1, 2);
+#endif
 void all_wait();
 int count_processors();
 int my_rank();
@@ -55,6 +59,7 @@ inline int am_master() { return my_rank() == 0; }
 bool with_mpi();
 
 void send(int from, int to, double *data, int size = 1);
+void broadcast(int from, float *data, int size);
 void broadcast(int from, double *data, int size);
 void broadcast(int from, char *data, int size);
 void broadcast(int from, int *data, int size);
@@ -67,15 +72,18 @@ bool broadcast(int from, bool);
 double max_to_master(double); // Only returns the correct value to proc 0.
 double max_to_all(double);
 int max_to_all(int);
+int min_to_all(int);
 float sum_to_master(float);   // Only returns the correct value to proc 0.
 double sum_to_master(double); // Only returns the correct value to proc 0.
 double sum_to_all(double);
+void sum_to_all(const float *in, float *out, int size);
 void sum_to_all(const double *in, double *out, int size);
 void sum_to_master(const float *in, float *out, int size);
 void sum_to_master(const double *in, double *out, int size);
 void sum_to_all(const float *in, double *out, int size);
 void sum_to_all(const std::complex<float> *in, std::complex<double> *out, int size);
 void sum_to_all(const std::complex<double> *in, std::complex<double> *out, int size);
+void sum_to_all(const std::complex<float> *in, std::complex<float> *out, int size);
 void sum_to_master(const std::complex<float> *in, std::complex<float> *out, int size);
 void sum_to_master(const std::complex<double> *in, std::complex<double> *out, int size);
 long double sum_to_all(long double);
