@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2021 Massachusetts Institute of Technology
+/* Copyright (C) 2005-2022 Massachusetts Institute of Technology
 %
 %  This program is free software; you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -32,9 +32,7 @@ int compare(double a, double b, const char *n, double eps = 4e-15) {
     master_printf("This gives a fractional error of %g\n", fabs(a - b) / fabs(b));
     return 0;
   }
-  else {
-    return 1;
-  }
+  else { return 1; }
 }
 
 int compare_point(fields &f1, fields &f2, const vec &p, double eps = 4e-8) {
@@ -293,29 +291,29 @@ int main(int argc, char **argv) {
   verbosity = 0;
   master_printf("Testing cylindrical coords under different splittings...\n");
 
-  if (!test_r_equals_zero(one)) abort("error in test_r_equals_zero");
+  if (!test_r_equals_zero(one)) meep::abort("error in test_r_equals_zero");
 
   for (int s = 2; s < 6; s++)
-    if (!test_pattern(one, s)) abort("error in test_pattern\n");
-  // if (!test_pattern(one, 8)) abort("error in crazy test_pattern\n");
-  // if (!test_pattern(one, 120)) abort("error in crazy test_pattern\n");
+    if (!test_pattern(one, s)) meep::abort("error in test_pattern\n");
+  // if (!test_pattern(one, 8)) meep::abort("error in crazy test_pattern\n");
+  // if (!test_pattern(one, 120)) meep::abort("error in crazy test_pattern\n");
 
   for (int s = 2; s < 4; s++)
-    if (!test_simple_periodic(one, s)) abort("error in test_simple_periodic\n");
+    if (!test_simple_periodic(one, s)) meep::abort("error in test_simple_periodic\n");
   // if (!test_simple_periodic(one, 8))
-  //  abort("error in crazy test_simple_periodic\n");
+  //  meep::abort("error in crazy test_simple_periodic\n");
   // if (!test_simple_periodic(one, 120))
-  //  abort("error in crazy test_simple_periodic\n");
+  //  meep::abort("error in crazy test_simple_periodic\n");
 
   for (int s = 2; s < 5; s++)
-    if (!test_simple_metallic(one, s)) abort("error in test_simple_metallic\n");
+    if (!test_simple_metallic(one, s)) meep::abort("error in test_simple_metallic\n");
   // if (!test_simple_metallic(one, 8))
-  //  abort("error in crazy test_simple_metallic\n");
+  //  meep::abort("error in crazy test_simple_metallic\n");
   // if (!test_simple_metallic(one, 120))
-  //  abort("error in crazy test_simple_metallic\n");
+  //  meep::abort("error in crazy test_simple_metallic\n");
 
   for (int s = 2; s < 6; s++)
-    if (!test_pml(one, s)) abort("error in test_pml\n");
+    if (!test_pml(one, s)) meep::abort("error in test_pml\n");
 
   return 0;
 }
