@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2021 Massachusetts Institute of Technology
+/* Copyright (C) 2005-2022 Massachusetts Institute of Technology
 %
 %  This program is free software; you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -45,9 +45,7 @@ int compare(double a, double b, const char *n) {
     master_printf("This gives a fractional error of %g\n", fabs(a - b) / fabs(b));
     return 0;
   }
-  else {
-    return 1;
-  }
+  else { return 1; }
 }
 
 int compare_point(fields &f1, fields &f2, const vec &p) {
@@ -230,16 +228,16 @@ int main(int argc, char **argv) {
   verbosity = 0;
   master_printf("Testing 3D...\n");
 
-  if (!test_pml(one)) abort("error in test_pml vacuum\n");
+  if (!test_pml(one)) meep::abort("error in test_pml vacuum\n");
 
   for (int s = 2; s < 7; s++)
-    if (!test_periodic(targets, s)) abort("error in test_periodic targets\n");
+    if (!test_periodic(targets, s)) meep::abort("error in test_periodic targets\n");
 
   for (int s = 2; s < 8; s++)
-    if (!test_metal(one, s)) abort("error in test_metal vacuum\n");
+    if (!test_metal(one, s)) meep::abort("error in test_metal vacuum\n");
 
   for (int s = 2; s < 4; s++)
-    if (!test_pml_splitting(one, s)) abort("error in test_pml_splitting vacuum\n");
+    if (!test_pml_splitting(one, s)) meep::abort("error in test_pml_splitting vacuum\n");
 
   return 0;
 }
